@@ -1,20 +1,21 @@
 #!/usr/bin/env python
+# SPDX-License-Identifier: GPL-3.0-only
+# Copyright 2019-2020 Michael R. Crusoe
+# Copyright 2020 Altair Wei
 """
 Unpacks the result of `cwltool --unpack`.
 
 Only tested with a single v1.0 workflow.
 """
 
-import os
-import sys
-import json
 import argparse
-from pathlib import Path
-from typing import IO, Any, Dict, List, MutableMapping, Set, Text, Union, cast
+import json
+import os
+from typing import IO, Any, MutableMapping, Set, Text, Union, cast
 
+from cwlformat.formatter import stringify_dict
 from ruamel import yaml
 from schema_salad.sourceline import SourceLine, add_lc_filename
-from cwlformat.formatter import stringify_dict
 
 
 def main() -> None:
@@ -201,7 +202,9 @@ def rewrite_schemadef(document: MutableMapping[str, Any]) -> Set[str]:
                 field["name"] = field["name"].split("/")[2]
                 rewrite_types(field, entry_file, True)
             with open(entry_file[1:], "a", encoding="utf-8") as entry_handle:
-                yaml.dump([entry], entry_handle, Dumper=yaml.RoundTripDumper)
+                yaml.main.dump(
+                    [entry], entry_handle, Dumper=yaml.dumper.RoundTripDumper
+                )
             entry["$import"] = entry_file[1:]
             del entry["name"]
             del entry["type"]
